@@ -213,6 +213,9 @@ def find_url(ext, site, tag, filename):
 @blueprint.route('<ext>/<site>/<tag>/<int:start>,<int:end>')  # for --ping
 @blueprint.route('<ext>/<site>/<tag>/<int:start>,<int:end>.json')
 @blueprint.route('<ext>/<site>/<tag>/<int:start>,<int:end>/<urltype>.json')
+@blueprint.route('<ext>/<site>/<tag>/<float:start>,<float:end>')  # for --ping
+@blueprint.route('<ext>/<site>/<tag>/<float:start>,<float:end>.json')
+@blueprint.route('<ext>/<site>/<tag>/<float:start>,<float:end>/<urltype>.json')
 @handle_errors_as_json
 @authentication.validate
 def find_urls(ext, site, tag, start, end, urltype=None):
