@@ -5,20 +5,15 @@
 """Test configuration for gwdatafind_server
 """
 
-import os
-from pathlib import Path
-from unittest import mock
-
 import pytest
 
-from gwdatafind_server import create_app
+from utils import create_test_app
 
 
-@mock.patch.dict("os.environ")
 @pytest.fixture
 def app():
-    os.environ["LDR_LOCATION"] = str(Path(__file__).parent)
-    return create_app()
+    # default app to noauth for ease
+    return create_test_app(auth="None")
 
 
 @pytest.fixture
